@@ -2,6 +2,7 @@ package WWW::SnipeIT::Hardware;
 use Modern::Perl '2018';
 
 use Object::Pad;
+use URI;
 
 use HTTP::Request;
 use LWP::UserAgent;
@@ -13,8 +14,6 @@ class Hardware {
     field $endpoint :param;
     field $header :param;
 
-
-
     method getHardwareIDByAssetTag ($assetTag) {
         my $url = $endpoint."hardware/bytag/".$assetTag;
         my $r = HTTP::Request->new('GET', $url, $header);
@@ -110,6 +109,19 @@ class Hardware {
 
         return $results;
     }
+
+    method getHardware (%params) {
+        my $uri = URI->new($endpoint."hardware");
+        while (my ($key, $value) = each %params) {
+            $uri->query_param($key => $value);
+        }
+        my $r = HTTP::Request->new('GET', $uri->as_string, $header);
+        my $ua = LWP::UserAgent->new();
+        my $res = $ua->request($r);
+        my $results = JSON::XS::decode_json($res->{_content});
+
+        return $results;
+    }
 }
 
 1;
\ No newline at end of file
